!!! note
    `rnzb` should only raise the errors documented on this page (currently just one). If you encounter any other errors, consider it a bug and report it.

::: rnzb.InvalidNzbError
    options:
        members: true
